Class: Defmastership::Modifier::UpdateErefChecksum
- Inherits:
-
UpdateEref
- Object
- UpdateEref
- Defmastership::Modifier::UpdateErefChecksum
- Defined in:
- lib/defmastership/modifier/update_eref_checksum.rb
Overview
Update external refs checksum
Defined Under Namespace
Modules: Helper
Instance Attribute Summary
Attributes included from ModifierCommon
Class Method Summary collapse
-
.replacement_methods ⇒ Array<Symbol>
Methods’s symbols will be called in sequence to perform the document modifications.
Methods inherited from UpdateEref
default_config, #do_modifications, #initialize, #replace_erefs
Methods included from ModifierCommon
#do_modifications, #method_missing, #respond_to_missing?, #setup_modifier_module
Constructor Details
This class inherits a constructor from Defmastership::Modifier::UpdateEref
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Defmastership::Modifier::ModifierCommon
Class Method Details
.replacement_methods ⇒ Array<Symbol>
Methods’s symbols will be called in sequence to perform the document modifications
13 14 15 |
# File 'lib/defmastership/modifier/update_eref_checksum.rb', line 13 def self.replacement_methods %i[replace_erefs] end |