Class: Defmastership::Modifier::UpdateIref
- Inherits:
-
Object
- Object
- Defmastership::Modifier::UpdateIref
- Includes:
- ModifierCommon
- Defined in:
- lib/defmastership/modifier/update_iref_common.rb
Overview
Update internal refs checksum
Direct Known Subclasses
Instance Attribute Summary
Attributes included from ModifierCommon
Class Method Summary collapse
-
.default_config ⇒ Hash{Symbol => Object}
The default configuration.
Instance Method Summary collapse
-
#do_modifications(adoc_sources) ⇒ Object
Apply the modifier on all provided asciidoc sources based on modifier’s
self.replacement_methodslist. -
#initialize(config) ⇒ UpdateIref
constructor
A new instance of UpdateIref.
Methods included from ModifierCommon
#method_missing, #respond_to_missing?, #setup_modifier_module
Constructor Details
#initialize(config) ⇒ UpdateIref
Returns a new instance of UpdateIref.
20 21 22 23 24 |
# File 'lib/defmastership/modifier/update_iref_common.rb', line 20 def initialize(config) @document = Document.new setup_modifier_module(config) end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Defmastership::Modifier::ModifierCommon
Class Method Details
.default_config ⇒ Hash{Symbol => Object}
Returns the default configuration.
15 16 17 |
# File 'lib/defmastership/modifier/update_iref_common.rb', line 15 def self.default_config {} end |
Instance Method Details
#do_modifications(adoc_sources) ⇒ Object
Apply the modifier on all provided asciidoc sources based on modifier’s self.replacement_methods list
32 33 34 35 36 37 38 |
# File 'lib/defmastership/modifier/update_iref_common.rb', line 32 def do_modifications(adoc_sources) adoc_sources.each_key do |adoc_file| document.parse_file_with_preprocessor(adoc_file) end super end |